#!/bin/tclsh

load tclrpc.so

source common.tcl

set INVALID INV
set SLEEP_TIME [expr 20 * 1000]

set hour 0
set minute 0
set delay 0

set trigger $INVALID

proc loadConfigFile { } {
	global hour minute delay
	
	array set content {HOUR 0 MINUTE 0 DELAY 0}
	catch { array set content [loadFromFile "/etc/config/addons/presence/trigger.conf"]}
		
	set hour $content(HOUR)
	set minute $content(MINUTE)
	set delay $content(DELAY)
}

proc getTime { } {
  set timeValue [clock seconds]
  set hour [clock format $timeValue -format %H]
  set minute [clock format $timeValue -format %M]
  
  return [expr (($hour * 60) + $minute)]
}

proc activate { } {
	catch {	xmlrpc 127.0.0.1:2001 setValue [list string BidCoS-RF:1] [list string PRESS_SHORT] [list bool 1] }
}


##
# Hauptprogramm.
##
proc main { } {
	global INVALID SLEEP_TIME hour minute delay trigger
	
	startup
  
	loadConfigFile
		
	while { 1 == 1 } {
		set now [getTime]

		if { ($trigger == $INVALID) && ($now <= [expr $hour * 60 + $minute]) } {
			set trigger [expr $hour * 60 + $minute + floor(rand() * $delay)]
			log "trigger set to $trigger"
		}

		if { ($trigger != $INVALID) && ($now >= $trigger) } {
			log "activate"
			activate
			set trigger $INVALID
		}

		after $SLEEP_TIME
	}
}

##
# Startet die Zusatzsoftware.
# Stellt sicher, dass die Zusatzsoftware nur einmal ausgefht wird und erstellt
# die PID-Datei.
##
proc startup { } {
  if {[isRunning]} then {
    error "already running"
  }

  writePidFile
	log "started"
}

#*******************************************************************************
# Einsprungpunkt
#*******************************************************************************

if { [catch { main } errorMessage] } then {
  log $errorMessage
  exit 1
}
